@@ -7,15 +7,6 @@
 
 ($klccin, $klibcconf, $perlpath) = @ARGV;
 
-# This should probably handle quotes and escapes...
-sub string2list($)
-{
-    my($s) = @_;
-
-    $s =~ s/\s+/\',\'/g;
-    return "(\'".$s."\')";
-}
-
 print "#!${perlpath}\n";
 
 open(KLIBCCONF, '<', $klibcconf) or die "$0: cannot open $klibcconf: $!\n";
@@ -24,7 +15,7 @@ while ( defined($l = <KLIBCCONF>) ) {
     if ( $l =~ /^([^=]+)\=(.*)$/ ) {
 	$n = $1;  $s = $2;
 	print "\$$n = \"\Q$s\E\";\n";
-	print "\@$n = ", string2list($s), ";\n";
+	print "\@$n = qw($s);\n";
 	print "\$conf{\'\L$n\E\'} = \\\$$n;\n";
     }
 }
